=========================
Contributing to Merchant
=========================

While there is no requirement for you to contribute your new gateway code or 
changes back to the `upstream project`_, you can play a good samaritan by
contributing back to the project and helping scores of people.

Here are the steps to follow to contribute back to Merchant_:

* Fork the project from it's `github page`_.
* Make the changes in your fork.
* File an issue at the `github page`_ and enclose a pull request.

  .. note:: 

    If you want to include a new gateway, we request you to include a few 
    tests (probably using the current tests as a template).

* Don't forget to add yourself to the `CONTRIBUTORS.txt` file before opening
  an issue.

.. _`upstream project`: http://github.com/agiliq/merchant
.. _Merchant: http://github.com/agiliq/merchant
.. _`github page`: http://github.com/agiliq/merchant
